;; Generated package description from gtags-mode.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "gtags-mode" "1.9.4.0.20251110.175010" "GNU Global integration with xref, project and imenu." '((emacs "28")) :commit "913da16515242c6ee26fd0f5af1a79b48a2daa29" :keywords '("xref" "project" "imenu" "gtags" "global") :url "https://github.com/Ergus/gtags-mode")
